@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, List, Optional
+from typing import TYPE_CHECKING, Any, List, Optional, Union
 from ain.account import Account, Accounts
 from ain.types import (
     TransactionBody,
@@ -6,6 +6,7 @@ from ain.types import (
     ECDSASignature,
 )
 from ain.utils import (
+    privateToAddress,
     toBytes,
     toChecksumAddress,
     bytesToHex,
@@ -15,6 +16,7 @@ from ain.utils import (
     ecRecoverPub,
     ecVerifySig,
 )
+from ain.utils.V3Keystore import V3Keystore, V3KeystoreOptions
 
 if TYPE_CHECKING:
     from ain.ain import Ain
@@ -90,12 +92,18 @@ class Wallet:
         self.accounts[account.address] = account
         return account.address
 
-    # TODO(kriii): implement this function.
-    def addFromV3Keystore(self):
+    def addFromV3Keystore(self, v3Keystore: Union[V3Keystore, str], password: str):
         """
         Adds an account from a V3 Keystore.
         """
-        pass
+        if type(v3Keystore) is V3Keystore:
+            privateKey = v3Keystore.toPrivateKey(password)
+        elif type(v3Keystore) is str:
+            privateKey = V3Keystore.fromJSON(v3Keystore).toPrivateKey(password)
+        else:
+            raise TypeError("v3Keystore has invalid type")
+        self.add(privateKey)
+        return privateToAddress(privateKey)
     
     def remove(self, address: str):
         """
@@ -166,7 +174,7 @@ class Wallet:
         fromAddr = self.getImpliedAddress(fromAddress)
         toAddr = toChecksumAddress(toAddress)
         transferRef = self.ain.db.ref(f"/transfer/{fromAddr}/{toAddr}").push()
-        return transferRef.setValue(
+        return await transferRef.setValue(
             ValueOnlyTransactionInput(
                 ref="/value",
                 address=fromAddress,
@@ -216,16 +224,29 @@ class Wallet:
     def verifySignature(self, data: Any, signature: str, address: str) -> bool:
         return ecVerifySig(data, signature, address, self.chainId)
 
-    # TODO(kriii): implement this function.
-    def toV3Keystore(self):
+    def toV3Keystore(
+        self,
+        password: str,
+        options: V3KeystoreOptions = V3KeystoreOptions()
+    ) -> List[V3Keystore]:
         """
         Save the accounts in the wallet as V3 Keystores, locking them with the password.
         """
-        pass
+        ret = []
+        for address in self.accounts:
+            ret.append(self.accountToV3Keystore(address, password, options))
+        return ret
     
-    # TODO(kriii): implement this function.
-    def accountToV3Keystore(self):
+    def accountToV3Keystore(
+        self,
+        address: str,
+        password: str,
+        options: V3KeystoreOptions = V3KeystoreOptions()
+    ) -> V3Keystore:
         """
         Converts an account into a V3 Keystore and encrypts it with a password.
         """
-        pass
\ No newline at end of file
+        if not self.isAdded(address):
+            raise ValueError("No such address exists in the wallet")
+        privateKey = self.accounts[address].private_key
+        return V3Keystore.fromPrivateKey(privateKey, password, options)
\ No newline at end of file
